/*
 * Copyright 2005-2006 Michelle Osmond Licensed under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law
 * or agreed to in writing, software distributed under the License is
 * distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */

package message.portlets;

import java.io.IOException;
import java.io.PrintWriter;
import java.net.URLEncoder;

import javax.portlet.ActionRequest;
import javax.portlet.ActionResponse;
import javax.portlet.GenericPortlet;
import javax.portlet.PortletException;
import javax.portlet.PortletRequest;
import javax.portlet.PortletSession;
import javax.portlet.RenderRequest;
import javax.portlet.RenderResponse;

import message.MessageHelper;

/**
 * A portlet that receives messages (locally named "author" and "book"), and
 * uses them to generate an Amazon search.
 * 
 * @author Michelle Osmond
 * @version 1.1
 * @see ListingPortlet
 * @see AmazonSearchBookPortlet
 */
public class AmazonSearchBookPortlet extends GenericPortlet
{
    public void doView(RenderRequest request, RenderResponse response) throws PortletException, IOException
    {
        PortletSession portletSession = request.getPortletSession(true);
        String id = getInstanceID(request);
        String msgSessionId = MessageHelper.getSessionID(request);

        // load this portlet's inputs and outputs from preferences
        MessageHelper.loadPrefs(request, id, msgSessionId);

        response.setContentType("text/html");
        PrintWriter writer = response.getWriter();

        writer.write("<p><i>portlet instance id: " + id + "</i></p>");

        // Generate the search URL from the Author/Book messages, if present
        String search = "http://www.amazon.co.uk/exec/obidos/search-handle-url/index=books-uk&field-keywords=";

        MessageHelper helper = new MessageHelper(portletSession, id, msgSessionId);
        String broadcastAuthor = helper.getAsString("author");
        if (broadcastAuthor != null && broadcastAuthor.length() > 0)
        {
            search += URLEncoder.encode(broadcastAuthor, "UTF-8");
        }
        String broadcastBook = helper.getAsString("book");
        if (broadcastBook != null && broadcastBook.length() > 0)
        {
            search += URLEncoder.encode(" " + broadcastBook, "UTF-8");
        }

        writer.write("<iframe src='" + search + "' width='900' height='400'>No iframes... <a href='" + search
                + "' target='_blank'>Search Amazon</a></iframe>");
    }

    public void doEdit(RenderRequest request, RenderResponse response) throws PortletException, IOException
    {
        doView(request, response);
    }

    public void doHelp(RenderRequest request, RenderResponse response) throws PortletException, IOException
    {
    }

    public void processAction(ActionRequest request, ActionResponse actionResponse) throws PortletException,
            java.io.IOException
    {
    }

    public String getInstanceID(PortletRequest request)
    {
        return "AmazonSearchBook" + MessageHelper.getPortletID(request);
    }
}
