/*
 * Copyright 2005-2006 Michelle Osmond Licensed under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law
 * or agreed to in writing, software distributed under the License is
 * distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */

package message.portlets;

import java.io.IOException;
import java.io.PrintWriter;
import java.net.URLEncoder;

import javax.portlet.ActionRequest;
import javax.portlet.ActionResponse;
import javax.portlet.PortletException;
import javax.portlet.PortletMode;
import javax.portlet.PortletRequest;
import javax.portlet.PortletSession;
import javax.portlet.RenderRequest;
import javax.portlet.RenderResponse;

import message.MessageHelper;
import message.MessageUtils;

/**
 * This is an example of a simple, complete portlet with message mappings
 * configurable by the portal user. There is one input mapping, with internal
 * name "search". It uses edit_mappings.jsp and the functions in MessageUtils to
 * do the dynamic mappings.
 * 
 * @author Michelle Osmond
 * @version 1.1
 * @see WiredListingPortlet
 * @see message.MessageUtils
 */
public class EbaySearchBookPortlet extends JSPPortlet
{
    public void doView(RenderRequest request, RenderResponse response) throws PortletException, IOException
    {

        PortletSession portletSession = request.getPortletSession(true);
        String id = getInstanceID(request);
        String msgSessionId = MessageHelper.getSessionID(request);

        // load this portlet's message mappings from preferences
        MessageHelper.loadPrefs(request, id, msgSessionId);

        response.setContentType("text/html");
        PrintWriter writer = response.getWriter();

        writer.write("<p><i>portlet instance id: " + id + "</i></p>");

        // Generate the search URL using the "search" message
        String search = "http://search.ebay.co.uk/search/search.dll?GetResult&category0=267&query=";
        MessageHelper helper = new MessageHelper(portletSession, id, msgSessionId);
        String broadcastSearch = helper.getAsString("search");
        if (broadcastSearch != null && broadcastSearch.length() > 0)
        {
            search += URLEncoder.encode(broadcastSearch, "UTF-8");
        }

        writer.write("<iframe src='" + search + "' width='900' height='400'>No iframes... <a href='" + search
                + "' target='_blank'>Search Ebay</a></iframe>");
    }

    public void doEdit(RenderRequest request, RenderResponse response) throws PortletException, IOException
    {
        String id = getInstanceID(request);
        String msgSessionId = MessageHelper.getSessionID(request);

        // load this portlet's inputs and outputs from preferences
        MessageHelper.loadPrefs(request, id, msgSessionId);

        MessageUtils.prepareMappingForm(request, id, msgSessionId);
        include(request, response, "/WEB-INF/jsp/edit_mappings.jsp");
    }

    public void doHelp(RenderRequest request, RenderResponse response) throws PortletException, IOException
    {
    }

    public void processAction(ActionRequest request, ActionResponse actionResponse) throws PortletException,
            java.io.IOException
    {
        if (request.getPortletMode().equals(PortletMode.EDIT))
        {
            String id = getInstanceID(request);
            String msgSessionId = MessageHelper.getSessionID(request);
            MessageUtils.processMappingForm(request, actionResponse, id, msgSessionId);
        }
    }

    public String getInstanceID(PortletRequest request)
    {
        return "EbaySearchBook" + MessageHelper.getPortletID(request);
    }
}
