/*
 * Copyright 2005-2006 Michelle Osmond Licensed under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law
 * or agreed to in writing, software distributed under the License is
 * distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */

package message.portlets;

import java.io.IOException;

import javax.portlet.GenericPortlet;
import javax.portlet.PortletContext;
import javax.portlet.PortletException;
import javax.portlet.PortletRequestDispatcher;
import javax.portlet.RenderRequest;
import javax.portlet.RenderResponse;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * A simple base portlet class with a function for including a JSP.
 * 
 * @author Michelle Osmond
 * @version 1.1
 */
public abstract class JSPPortlet extends GenericPortlet
{
    private static final Log log = LogFactory.getLog(JSPPortlet.class);

    /**
     * function to include a jsp or servlet.
     */
    protected void include(RenderRequest request, RenderResponse response, String path) throws PortletException,
            IOException
    {
        PortletContext ctx = getPortletContext();
        PortletRequestDispatcher dispatcher = ctx.getRequestDispatcher(path);
        if (dispatcher != null)
        {
            dispatcher.include(request, response);
        }
        else
        {
            log.warn("Unable to dispatch to " + path);
        }
    }
}
