/*
 * Copyright 2005-2006 Michelle Osmond Licensed under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law
 * or agreed to in writing, software distributed under the License is
 * distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */

package message.portlets;

import java.util.HashMap;
import java.util.Map;
import java.util.SortedMap;
import java.util.SortedSet;
import java.util.TreeMap;
import java.util.TreeSet;

/**
 * A class used by some of the example portlets as a data source.
 * 
 * @author Michelle Osmond
 * @version 1.1
 * @see ListingPortlet
 * @see AuthorDetailsPortlet
 */
public class Library
{
    protected static SortedMap listing = null;

    protected static Map authorWebsite = null;

    static
    {
        listing = new TreeMap();
        SortedSet books = null;

        books = new TreeSet();
        books.add("The Colour of Magic");
        books.add("Wyrd Sisters");
        books.add("Mort");
        books.add("Pyramids");
        listing.put("Terry Pratchett", books);

        books = new TreeSet();
        books.add("Falling Free");
        books.add("Barrayar");
        books.add("The Curse of Chalion");
        listing.put("Lois McMaster Bujold", books);

        books = new TreeSet();
        books.add("The End of Eternity");
        books.add("Foundation and Earth");
        books.add("I, Robot");
        books.add("Buy Jupiter");
        books.add("The Stars Like Dust");
        listing.put("Isaac Asimov", books);

        books = new TreeSet();
        books.add("Mostly Harmless");
        books.add("The Salmon of Doubt");
        listing.put("Douglas Adams", books);

        authorWebsite = new HashMap();
        authorWebsite.put("Terry Pratchett", "http://www.lspace.org");
        authorWebsite.put("Lois McMaster Bujold", "http://www.dendarii.com/");
        authorWebsite.put("Isaac Asimov", "http://www.asimovonline.com/");
        authorWebsite.put("Douglas Adams", "http://www.douglasadams.com/");
    }

    public Library()
    {
    }

    public static SortedMap getListing()
    {
        return listing;
    }

    public static SortedSet getBooks(String author)
    {
        if (listing.containsKey(author))
        {
            return (SortedSet) listing.get(author);
        }
        return new TreeSet();
    }

    public static String getWebsite(String author)
    {
        if (authorWebsite.containsKey(author))
        {
            return authorWebsite.get(author).toString();
        }
        return "http://www.google.co.uk/search?q=" + author;
    }
}
