/*
 * Copyright 2005-2006 Michelle Osmond Licensed under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law
 * or agreed to in writing, software distributed under the License is
 * distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */

package message.portlets;

import java.io.IOException;
import java.io.PrintWriter;

import javax.portlet.ActionRequest;
import javax.portlet.ActionResponse;
import javax.portlet.GenericPortlet;
import javax.portlet.PortletException;
import javax.portlet.PortletMode;
import javax.portlet.PortletRequest;
import javax.portlet.PortletURL;
import javax.portlet.RenderRequest;
import javax.portlet.RenderResponse;

import message.MessageHelper;
import message.MessageUtils;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * Example portlet for demonstrating the use of the messaging library.
 * 
 * @see message.portlets.Portlet2
 * 
 * @author Michelle Osmond
 * @version 1.1
 */
public class Portlet1 extends GenericPortlet
{
    private static final Log log = LogFactory.getLog(Portlet1.class);

    protected void doView(RenderRequest request, RenderResponse response) throws PortletException, IOException
    {
        String id = this.getInstanceID(request);
        String msgSessionId = MessageHelper.getSessionID(request);
        MessageHelper.loadPrefs(request, id, msgSessionId);

        response.setContentType("text/html");
        PrintWriter out = response.getWriter();

        out.println("<h4>Portlet1</h4>");

        out.println("<p><b>Message Session ID:</b> " + msgSessionId + "<br />");
        out.println("<b>Portlet ID:</b> " + id + "<br />");
        out.println("<b>Portlet App:</b> " + request.getContextPath() + "</p>");

        out
            .println("<p>This portlet will send a message, referring to it as \"<code>a_val</code>\" in its code.<br />");
        out
            .println("The portlet's default preferences in <code>portlet.xml</code> have been set up so that "
                    + "this local \"<code>a_val</code>\" message will be published to a public message box named \"<code>b_val</code>\"."
                    + " (<a href=\"" + request.getContextPath()
                    + "/portlet1_prefs.html\" target=\"_blank\">show me</a>)</p>");

        out.println("<h4>Send the Message</h4>");
        out.println("<p>Send message (in processAction): <br />"
                + "<code>MessageHelper .send(\"a_val\",\"{your input}: This is a message...\")</code>");

        PortletURL aURL = response.createActionURL();
        out.println("<form action=\"" + aURL.toString() + "\" method=\"POST\">");
        out.println(" <input type=\"text\" name=\"your_message\" />");
        out.println(" <input type=\"submit\" value=\"Send it!\" /></form></p>");

        out.println("<h4>Read back the Message</h4>");
        out.println("<p>");
        out.println("After it has been sent, you can always read back the same message within this portlet, "
                + "continuing to refer to it by the local name (\"<code>a_val</code>\"). "
                + "This will always return the last value sent for this message by this portlet.");
        out.println("</p>");

        MessageHelper msgHelper = new MessageHelper(request.getPortletSession(true), id, msgSessionId);
        String msg = (String) msgHelper.get("a_val");
        out.println("<p>Retrieve message that we sent: <code>MessageHelper .get(\"a_val\")</code> = ");
        if (msg != null && msg.length() > 0)
        {
            out.println("<b style=\"color:#00aa00\">" + msg + "</b></p>");
        }
        else
        {
            out.println("<b style=\"color:#aa0000\">" + msg
                    + "</b> (no message has been sent from this portlet yet)</p>");
        }

        out.println("<h4>Advanced Configuration of Mappings</h4>");
        out.println("<p>If you like, you can change the message 'mapping' in Edit mode"
                + " so that the \"<code>a_val</code>\" message is published to a different message box.</i>");
    }

    public void processAction(ActionRequest request, ActionResponse response) throws PortletException, IOException
    {
        String id = this.getInstanceID(request);
        String msgSessionId = MessageHelper.getSessionID(request);
        MessageHelper.loadPrefs(request, id, msgSessionId);

        if (request.getPortletMode().equals(PortletMode.EDIT))
        {
            // Process the Edit Mappings form
            MessageUtils.processMappingForm(request, response, id, msgSessionId);
        }
        else if (request.getPortletMode().equals(PortletMode.VIEW))
        {
            // Send the message
            log.debug("try sending message from Portlet 1 in webapp " + request.getContextPath());
            MessageHelper msgh = new MessageHelper(request.getPortletSession(true), id, msgSessionId);
            msgh.send("a_val", request.getParameter("your_message") + ": This is a message from Portlet1 [" + id
                    + "] in portlet webapp " + request.getContextPath());
        }
    }

    protected void doEdit(RenderRequest request, RenderResponse response) throws PortletException, IOException
    {
        // Prepare the Edit Mappings form, which allows users to change the
        // names of the message boxes
        String id = this.getInstanceID(request);
        String msgSessionId = MessageHelper.getSessionID(request);
        MessageHelper.loadPrefs(request, id, msgSessionId);

        MessageUtils.prepareMappingForm(request, id, msgSessionId);
        getPortletContext().getRequestDispatcher("/WEB-INF/jsp/edit_mappings.jsp").include(request, response);
    }

    public String getInstanceID(PortletRequest request)
    {
        // To make it easier to identify messages when using the debug
        // MessageReaderPortlet
        return "Portlet1" + MessageHelper.getPortletID(request);
    }
}
