/*
 * Copyright 2005-2006 Michelle Osmond Licensed under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law
 * or agreed to in writing, software distributed under the License is
 * distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */

package message.portlets;

import java.io.IOException;

import javax.portlet.ActionRequest;
import javax.portlet.ActionResponse;
import javax.portlet.PortletException;
import javax.portlet.PortletMode;
import javax.portlet.PortletRequest;
import javax.portlet.RenderRequest;
import javax.portlet.RenderResponse;

import message.MessageHelper;
import message.MessageUtils;

/**
 * This is an example of a portlet with message mappings configurable by the
 * portal user. It extends ListingPortlet, adding this new functionality. It
 * uses edit_mappings.jsp and the functions in MessageUtils to do the dynamic
 * mappings.
 * 
 * @author Michelle Osmond
 * @version 1.1
 * @see EbaySearchBookPortlet
 * @see message.MessageUtils
 */
public class WiredListingPortlet extends ListingPortlet
{

    public void doView(RenderRequest request, RenderResponse response) throws PortletException, IOException
    {
        // do the normal view
        super.doView(request, response);
    }

    public void doEdit(RenderRequest request, RenderResponse response) throws PortletException, IOException
    {
        String id = getInstanceID(request);
        String msgSessionId = MessageHelper.getSessionID(request);

        // load this portlet's inputs and outputs from preferences
        MessageHelper.loadPrefs(request, id, msgSessionId);

        MessageUtils.prepareMappingForm(request, id, msgSessionId);
        include(request, response, "/WEB-INF/jsp/edit_mappings.jsp");
    }

    public void processAction(ActionRequest request, ActionResponse actionResponse) throws PortletException,
            java.io.IOException
    {
        if (request.getPortletMode().equals(PortletMode.EDIT))
        {
            String id = getInstanceID(request);
            String msgSessionId = MessageHelper.getSessionID(request);
            MessageUtils.processMappingForm(request, actionResponse, id, msgSessionId);

        }
        else if (request.getPortletMode().equals(PortletMode.VIEW))
        {
            super.processAction(request, actionResponse);
        }
    }

    public String getInstanceID(PortletRequest request)
    {
        return "WiredListing" + MessageHelper.getPortletID(request);
    }
}
