/*
 * Copyright 2005-2006 Michelle Osmond Licensed under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law
 * or agreed to in writing, software distributed under the License is
 * distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */

package message;

import java.util.HashMap;
import java.util.Properties;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * Access to messaging configuration: message.PortletMessaging.properties You
 * can define classes to use for the MessageStore ("message.store"), and
 * SessionIDRetriever ("session.id.retriever").
 * 
 * @author Michelle Osmond
 * @version 1.2
 */
public class MessageConfig
{
    private static final Log log = LogFactory.getLog(MessageConfig.class);

    public static String MESSAGE_STORE = "message.store";

    public static String SESSION_ID_RETRIEVER = "session.id.retriever";

    public static HashMap default_properties = new HashMap();

    protected static Properties props = new Properties();

    static
    {
        default_properties.put(MESSAGE_STORE, "message.store.BasicMessageStore");
        default_properties.put(SESSION_ID_RETRIEVER, "message.retriever.NamespacedLocalSessionIDRetriever");

        try
        {
            props.load(MessageConfig.class.getResourceAsStream("/message/PortletMessaging.properties"));
        }
        catch (Exception e)
        {
            log.warn("Could not find message/PortletMessaging.properties in the classpath. (" + e.getMessage()
                    + ") Default classes will be used.");
        }
    }

    public static String getConfigProperty(String name)
    {
        String value = props.getProperty(name);

        if (value == null)
        {
            if (log.isDebugEnabled())
            {
                log.debug("MessageConfig unable to retrieve config property; reverting to default for " + name);
            }
            value = (String) default_properties.get(name);
        }

        return value;
    }
}
