/*
 * Copyright 2005-2006 Michelle Osmond Licensed under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law
 * or agreed to in writing, software distributed under the License is
 * distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */

package message;

import java.util.Map;
import java.util.Set;

/**
 * Storage and retrieval of portlet message mappings, and the messages.
 * Implement this interface if you want to create a custom Message Store.
 * 
 * @author Michelle Osmond
 * @version 1.2
 * @see MessageCentre
 */
public interface MessageStore
{

    void initialise(String sessionID);

    void saveInputMapping(MessageBoxKey key, MessageBoxKey source);

    void deleteInput(MessageBoxKey key);

    void saveOutputMapping(MessageBoxKey key, MessageBoxKey target);

    void clearAllOutputMappings(MessageBoxKey key);

    void deleteOutput(MessageBoxKey key);

    Set findOutputTargets(MessageBoxKey key);

    MessageBoxKey getInputSource(MessageBoxKey key);

    Object getMessage(MessageBoxKey key);

    void sendMessage(Set targetKeys, Object message);

    Set getInputKeys(String portletID);

    Set getOutputKeys(String portletID);

    Set getPublicBoxKeys();

    Map getBoxes();

    Set getAllInputKeys();

    Set getAllOutputKeys();

    boolean isValid();

}
