/*
 * Copyright 2005-2006 Michelle Osmond Licensed under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law
 * or agreed to in writing, software distributed under the License is
 * distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */

package message.portlets;

import java.io.IOException;
import java.io.PrintWriter;
import java.util.Iterator;
import java.util.Map;
import java.util.Set;

import javax.portlet.ActionRequest;
import javax.portlet.ActionResponse;
import javax.portlet.GenericPortlet;
import javax.portlet.PortletException;
import javax.portlet.PortletSession;
import javax.portlet.RenderRequest;
import javax.portlet.RenderResponse;

import message.MessageBoxKey;
import message.MessageCentre;
import message.MessageHelper;

/**
 * A message snooper portlet for debugging. Shows all existing message boxes and
 * their contents, and lists all input/output mappings registered at the
 * MessageCentre.
 * 
 * @author Michelle Osmond
 * @version 1.1
 * @see message.MessageCentre
 */
public class MessageReaderPortlet extends GenericPortlet
{

    public void processAction(ActionRequest request, ActionResponse actionResponse) throws PortletException,
            java.io.IOException
    {
    }

    public void doView(RenderRequest request, RenderResponse response) throws PortletException, IOException
    {

        PortletSession portletSession = request.getPortletSession(true);

        response.setContentType("text/html");
        PrintWriter writer = response.getWriter();

        String msgSessionId = MessageHelper.getSessionID(request);
        MessageCentre centre = MessageHelper.getMessageCentre(portletSession, msgSessionId);
        Set inputKeys = centre.getAllInputKeys();
        Set outputKeys = centre.getAllOutputKeys();
        Map boxes = centre.getBoxes();

        writer.write("<p><b>Messages present:</b></p>");

        writer.write("<table border='1'>");
        writer.write("<tr><th>Box key</th><th>Box contents</th></tr>");

        if (boxes != null)
        {
            for (Iterator it = boxes.keySet().iterator(); it.hasNext();)
            {
                MessageBoxKey boxKey = (MessageBoxKey) it.next();
                writer.write("<tr>");
                writer.write("<td>" + boxKey.toString() + "</td>");
                writer.write("<td><pre>" + boxes.get(boxKey) + "</pre></td>");
                writer.write("</tr>");
            }
        }

        writer.write("</table>");

        writer.write("<br />");

        writer.write("<table border='1'>");
        writer.write("<tr><th>Input key</th><th>Source key</th><th>Source contents</th></tr>");

        if (inputKeys != null)
        {
            for (Iterator it = inputKeys.iterator(); it.hasNext();)
            {
                MessageBoxKey inputKey = (MessageBoxKey) it.next();
                MessageBoxKey sourceKey = centre.findInputSource(inputKey);
                writer.write("<tr>");
                writer.write("<td>" + inputKey.toString() + "</td>");
                writer.write("<td>" + sourceKey.toString() + "</td>");
                writer.write("<td><pre>" + boxes.get(sourceKey) + "</pre></td>");
                writer.write("</tr>");
            }
        }
        writer.write("</table>");

        writer.write("<br />");

        writer.write("<table border='1'>");
        writer.write("<tr><th>Output key</th><th>Target key</th><th>Target contents</th></tr>");

        if (outputKeys != null)
        {
            for (Iterator it = outputKeys.iterator(); it.hasNext();)
            {
                MessageBoxKey outputKey = (MessageBoxKey) it.next();
                Set sourceKeys = centre.findOutputTargets(outputKey);
                for (Iterator it2 = sourceKeys.iterator(); it2.hasNext();)
                {
                    MessageBoxKey sourceKey = (MessageBoxKey) it2.next();
                    writer.write("<tr>");
                    writer.write("<td>" + outputKey.toString() + "</td>");
                    writer.write("<td>" + sourceKey.toString() + "</td>");
                    writer.write("<td><pre>" + boxes.get(sourceKey) + "</pre></td>");
                    writer.write("</tr>");
                }
            }
        }

        writer.write("</table>");

        writer.write("<br />");
    }

    public void doEdit(RenderRequest request, RenderResponse response) throws PortletException, IOException
    {
        doView(request, response);
    }

    public void doHelp(RenderRequest request, RenderResponse response) throws PortletException, IOException
    {
    }

}
